Struct rivet_matchmaker::client::fluent_builders::ListRegions
source · [−]pub struct ListRegions<C, M, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to ListRegions.
Returns a list of regions available to this namespace. Regions are sorted by most optimal to least optimal. The player’s IP address is used to calculate the regions’ optimality.
Implementations
sourceimpl<C, M, R> ListRegions<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> ListRegions<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
sourcepub async fn send(self) -> Result<ListRegionsOutput, SdkError<ListRegionsError>> where
R::Policy: SmithyRetryPolicy<ListRegionsInputOperationOutputAlias, ListRegionsOutput, ListRegionsError, ListRegionsInputOperationRetryAlias>,
pub async fn send(self) -> Result<ListRegionsOutput, SdkError<ListRegionsError>> where
R::Policy: SmithyRetryPolicy<ListRegionsInputOperationOutputAlias, ListRegionsOutput, ListRegionsError, ListRegionsInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.