pub struct PlayerDisconnected<C, M, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to PlayerDisconnected.
Marks a player as disconnected. # Ghost Players If players are not marked as disconnected, lobbies will result with “ghost players” that the matchmaker thinks exist but are no longer connected to the lobby.
Implementations
Sourceimpl<C, M, R> PlayerDisconnected<C, M, R>
impl<C, M, R> PlayerDisconnected<C, M, R>
Sourcepub async fn send(
self,
) -> Result<PlayerDisconnectedOutput, SdkError<PlayerDisconnectedError>>where
R::Policy: SmithyRetryPolicy<PlayerDisconnectedInputOperationOutputAlias, PlayerDisconnectedOutput, PlayerDisconnectedError, PlayerDisconnectedInputOperationRetryAlias>,
pub async fn send(
self,
) -> Result<PlayerDisconnectedOutput, SdkError<PlayerDisconnectedError>>where
R::Policy: SmithyRetryPolicy<PlayerDisconnectedInputOperationOutputAlias, PlayerDisconnectedOutput, PlayerDisconnectedError, PlayerDisconnectedInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn player_token(self, input: impl Into<String>) -> Self
pub fn player_token(self, input: impl Into<String>) -> Self
A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.
Sourcepub fn set_player_token(self, input: Option<String>) -> Self
pub fn set_player_token(self, input: Option<String>) -> Self
A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.