#[non_exhaustive]
pub enum ListLobbiesErrorKind {
InternalError(InternalError),
RateLimitError(RateLimitError),
ForbiddenError(ForbiddenError),
UnauthorizedError(UnauthorizedError),
NotFoundError(NotFoundError),
BadRequestError(BadRequestError),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the ListLobbies operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InternalError(InternalError)
An error caused by internal server problems.
RateLimitError(RateLimitError)
An error thrown when the requestee has hit a rate limit. You are sending too many requests too quickly.
ForbiddenError(ForbiddenError)
An error thrown when the requestee requests a resource they do not have access to.
UnauthorizedError(UnauthorizedError)
An error thrown when the requestee is not authenticated.
NotFoundError(NotFoundError)
An error thrown when the requestee requests a non existant resource.
BadRequestError(BadRequestError)
An error thrown when the requestee has sent an invalid or malformed request.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code