#[non_exhaustive]
pub struct Builder { /* private fields */ }
A builder for FindLobbyInput

Implementations

Appends an item to game_modes.

To override the contents of this collection use set_game_modes.

Game modes to match lobbies against.

Game modes to match lobbies against.

Appends an item to regions.

To override the contents of this collection use set_regions.

Regions to match lobbies against. If not specified, the optimal region will be determined and will attempt to find lobbies in that region.

Regions to match lobbies against. If not specified, the optimal region will be determined and will attempt to find lobbies in that region.

Prevents a new lobby from being created when finding a lobby. If no lobby is found, a MATCHMAKER_LOBBY_NOT_FOUND error will be thrown.

Prevents a new lobby from being created when finding a lobby. If no lobby is found, a MATCHMAKER_LOBBY_NOT_FOUND error will be thrown.

Methods to verify a captcha.

Methods to verify a captcha.

Consumes the builder and constructs a FindLobbyInput