Struct rivet_matchmaker::input::player_connected_input::Builder
source · [−]#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for PlayerConnectedInput
Implementations
sourceimpl Builder
impl Builder
sourcepub fn player_token(self, input: impl Into<String>) -> Self
pub fn player_token(self, input: impl Into<String>) -> Self
A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.
sourcepub fn set_player_token(self, input: Option<String>) -> Self
pub fn set_player_token(self, input: Option<String>) -> Self
A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.
sourcepub fn build(self) -> Result<PlayerConnectedInput, BuildError>
pub fn build(self) -> Result<PlayerConnectedInput, BuildError>
Consumes the builder and constructs a PlayerConnectedInput