Struct rivet_matchmaker::input::FindLobbyInput
source · [−]#[non_exhaustive]pub struct FindLobbyInput {
pub game_modes: Option<Vec<String>>,
pub regions: Option<Vec<String>>,
pub prevent_auto_create_lobby: Option<bool>,
pub captcha: Option<CaptchaConfig>,
pub origin: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.game_modes: Option<Vec<String>>Game modes to match lobbies against.
regions: Option<Vec<String>>Regions to match lobbies against. If not specified, the optimal region will be determined and will attempt to find lobbies in that region.
prevent_auto_create_lobby: Option<bool>Prevents a new lobby from being created when finding a lobby. If no lobby is found, a MATCHMAKER_LOBBY_NOT_FOUND error will be thrown.
captcha: Option<CaptchaConfig>Methods to verify a captcha.
origin: Option<String>Implementations
sourceimpl FindLobbyInput
impl FindLobbyInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<FindLobby, ()>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<FindLobby, ()>, BuildError>
Consumes the builder and constructs an Operation<FindLobby>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture FindLobbyInput
sourceimpl FindLobbyInput
impl FindLobbyInput
sourcepub fn game_modes(&self) -> Option<&[String]>
pub fn game_modes(&self) -> Option<&[String]>
Game modes to match lobbies against.
sourcepub fn regions(&self) -> Option<&[String]>
pub fn regions(&self) -> Option<&[String]>
Regions to match lobbies against. If not specified, the optimal region will be determined and will attempt to find lobbies in that region.
sourcepub fn prevent_auto_create_lobby(&self) -> Option<bool>
pub fn prevent_auto_create_lobby(&self) -> Option<bool>
Prevents a new lobby from being created when finding a lobby. If no lobby is found, a MATCHMAKER_LOBBY_NOT_FOUND error will be thrown.
sourcepub fn captcha(&self) -> Option<&CaptchaConfig>
pub fn captcha(&self) -> Option<&CaptchaConfig>
Methods to verify a captcha.
pub fn origin(&self) -> Option<&str>