Struct rivet_matchmaker::input::PlayerDisconnectedInput
source · [−]Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.player_token: Option<String>A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.
Implementations
sourceimpl PlayerDisconnectedInput
impl PlayerDisconnectedInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<PlayerDisconnected, ()>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<PlayerDisconnected, ()>, BuildError>
Consumes the builder and constructs an Operation<PlayerDisconnected>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture PlayerDisconnectedInput
sourceimpl PlayerDisconnectedInput
impl PlayerDisconnectedInput
sourcepub fn player_token(&self) -> Option<&str>
pub fn player_token(&self) -> Option<&str>
A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.