Struct rivet_matchmaker::model::GameModeInfo
source · [−]Expand description
A game mode that the player can join.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.game_mode_id: Option<String>A human readable short identifier used to references resources. Different than a rivet.common#Uuid because this is intended to be human readable. Different than rivet.common#DisplayName because this should not include special characters and be short.
Implementations
sourceimpl GameModeInfo
impl GameModeInfo
sourcepub fn game_mode_id(&self) -> Option<&str>
pub fn game_mode_id(&self) -> Option<&str>
A human readable short identifier used to references resources. Different than a rivet.common#Uuid because this is intended to be human readable. Different than rivet.common#DisplayName because this should not include special characters and be short.
sourceimpl GameModeInfo
impl GameModeInfo
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture GameModeInfo