#[non_exhaustive]pub struct MatchmakerLobbyJoinInfoPlayer {
pub token: Option<String>,
}Expand description
A matchmaker lobby player.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.token: Option<String>Pass this token through the socket to the lobby server. The lobby server will validate this token with rivet.api.matchmaker#PlayerConnected$player_token.
Implementations
Sourceimpl MatchmakerLobbyJoinInfoPlayer
impl MatchmakerLobbyJoinInfoPlayer
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture MatchmakerLobbyJoinInfoPlayer