#[non_exhaustive]pub struct MatchmakerLobbyJoinInfoRegion {
pub region_id: Option<String>,
pub display_name: Option<String>,
}Expand description
A matchmaker lobby region.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.region_id: Option<String>A human readable short identifier used to references resources. Different than a rivet.common#Uuid because this is intended to be human readable. Different than rivet.common#DisplayName because this should not include special characters and be short.
display_name: Option<String>Represent a resource’s readable display name.
Implementations
Sourceimpl MatchmakerLobbyJoinInfoRegion
impl MatchmakerLobbyJoinInfoRegion
Sourcepub fn region_id(&self) -> Option<&str>
pub fn region_id(&self) -> Option<&str>
A human readable short identifier used to references resources. Different than a rivet.common#Uuid because this is intended to be human readable. Different than rivet.common#DisplayName because this should not include special characters and be short.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
Represent a resource’s readable display name.
Sourceimpl MatchmakerLobbyJoinInfoRegion
impl MatchmakerLobbyJoinInfoRegion
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture MatchmakerLobbyJoinInfoRegion