#[non_exhaustive]pub struct RegionInfo {
pub region_id: Option<String>,
pub provider_display_name: Option<String>,
pub region_display_name: Option<String>,
pub datacenter_coord: Option<Coord>,
pub datacenter_distance_from_client: Option<Distance>,
}Expand description
A region that the player can connect to.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.region_id: Option<String>A human readable short identifier used to references resources. Different than a rivet.common#Uuid because this is intended to be human readable. Different than rivet.common#DisplayName because this should not include special characters and be short.
provider_display_name: Option<String>A universally unique identifier.
region_display_name: Option<String>A universally unique identifier.
datacenter_coord: Option<Coord>Geographical coordinates for a location on Planet Earth.
datacenter_distance_from_client: Option<Distance>Distance available in multiple units.
Implementations
Sourceimpl RegionInfo
impl RegionInfo
Sourcepub fn region_id(&self) -> Option<&str>
pub fn region_id(&self) -> Option<&str>
A human readable short identifier used to references resources. Different than a rivet.common#Uuid because this is intended to be human readable. Different than rivet.common#DisplayName because this should not include special characters and be short.
Sourcepub fn provider_display_name(&self) -> Option<&str>
pub fn provider_display_name(&self) -> Option<&str>
A universally unique identifier.
Sourcepub fn region_display_name(&self) -> Option<&str>
pub fn region_display_name(&self) -> Option<&str>
A universally unique identifier.
Sourcepub fn datacenter_coord(&self) -> Option<&Coord>
pub fn datacenter_coord(&self) -> Option<&Coord>
Geographical coordinates for a location on Planet Earth.
Sourcepub fn datacenter_distance_from_client(&self) -> Option<&Distance>
pub fn datacenter_distance_from_client(&self) -> Option<&Distance>
Distance available in multiple units.
Sourceimpl RegionInfo
impl RegionInfo
Sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture RegionInfo