pub struct PlayerDisconnected<C, M, R = Standard> { /* private fields */ }
Fluent builder constructing a request to PlayerDisconnected.

Marks a player as disconnected. # Ghost Players If players are not marked as disconnected, lobbies will result with “ghost players” that the matchmaker thinks exist but are no longer connected to the lobby.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.

A JSON Web Token. Slightly modified to include a description prefix and use Protobufs of JSON.