Struct rivet_matchmaker::input::find_lobby_input::Builder
source · [−]#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for FindLobbyInput
Implementations
sourceimpl Builder
impl Builder
sourcepub fn game_modes(self, input: impl Into<String>) -> Self
pub fn game_modes(self, input: impl Into<String>) -> Self
Appends an item to game_modes.
To override the contents of this collection use set_game_modes.
Game modes to match lobbies against.
sourcepub fn set_game_modes(self, input: Option<Vec<String>>) -> Self
pub fn set_game_modes(self, input: Option<Vec<String>>) -> Self
Game modes to match lobbies against.
sourcepub fn regions(self, input: impl Into<String>) -> Self
pub fn regions(self, input: impl Into<String>) -> Self
Appends an item to regions.
To override the contents of this collection use set_regions.
Regions to match lobbies against. If not specified, the optimal region will be determined and will attempt to find lobbies in that region.
sourcepub fn set_regions(self, input: Option<Vec<String>>) -> Self
pub fn set_regions(self, input: Option<Vec<String>>) -> Self
Regions to match lobbies against. If not specified, the optimal region will be determined and will attempt to find lobbies in that region.
sourcepub fn prevent_auto_create_lobby(self, input: bool) -> Self
pub fn prevent_auto_create_lobby(self, input: bool) -> Self
Prevents a new lobby from being created when finding a lobby. If no lobby is found, a MATCHMAKER_LOBBY_NOT_FOUND error will be thrown.
sourcepub fn set_prevent_auto_create_lobby(self, input: Option<bool>) -> Self
pub fn set_prevent_auto_create_lobby(self, input: Option<bool>) -> Self
Prevents a new lobby from being created when finding a lobby. If no lobby is found, a MATCHMAKER_LOBBY_NOT_FOUND error will be thrown.
sourcepub fn captcha(self, input: CaptchaConfig) -> Self
pub fn captcha(self, input: CaptchaConfig) -> Self
Methods to verify a captcha.
sourcepub fn set_captcha(self, input: Option<CaptchaConfig>) -> Self
pub fn set_captcha(self, input: Option<CaptchaConfig>) -> Self
Methods to verify a captcha.
pub fn origin(self, input: impl Into<String>) -> Self
pub fn set_origin(self, input: Option<String>) -> Self
sourcepub fn build(self) -> Result<FindLobbyInput, BuildError>
pub fn build(self) -> Result<FindLobbyInput, BuildError>
Consumes the builder and constructs a FindLobbyInput